package com.ainirobot.orionaudiorecord;

import android.Manifest;
import android.content.pm.PackageManager;
import android.media.AudioFormat;
import android.os.Bundle;
import android.support.v4.app.ActivityCompat;
import android.support.v4.content.ContextCompat;
import android.support.v7.app.AppCompatActivity;
import android.util.Log;
import android.view.View;
import android.widget.Toast;

import butterknife.ButterKnife;
import butterknife.OnClick;

public class MainActivity extends AppCompatActivity {

    private static final int PERMISSIONS_REQUEST_RECORD_AUDIO = 1;
    private String TAG = MainActivity.class.getSimpleName();

    @Override
    protected void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        setContentView(R.layout.activity_main);
        ButterKnife.bind(this);
        if (ContextCompat.checkSelfPermission(this,
                Manifest.permission.RECORD_AUDIO)
                != PackageManager.PERMISSION_GRANTED || ContextCompat.checkSelfPermission(this,
                Manifest.permission.WRITE_EXTERNAL_STORAGE)
                != PackageManager.PERMISSION_GRANTED) {
            ActivityCompat.requestPermissions(this,
                    new String[]{Manifest.permission.RECORD_AUDIO, Manifest.permission.WRITE_EXTERNAL_STORAGE},
                    PERMISSIONS_REQUEST_RECORD_AUDIO);
        }
    }

    @Override
    public void onRequestPermissionsResult(int requestCode, String[] permissions, int[] grantResults) {

        if (requestCode == PERMISSIONS_REQUEST_RECORD_AUDIO) {
            if (grantResults[0] == PackageManager.PERMISSION_GRANTED && grantResults[1] == PackageManager.PERMISSION_GRANTED) {
                Toast.makeText(MainActivity.this, "permission granted,please start record", Toast.LENGTH_SHORT).show();
            } else {
                // Permission Denied
                Toast.makeText(MainActivity.this, "Permission Denied", Toast.LENGTH_SHORT).show();
                finish();
            }
            return;
        }
        super.onRequestPermissionsResult(requestCode, permissions, grantResults);
    }

    @OnClick({R.id.bt_startRecord, R.id.bt_stopRecord})
    public void onclick(View view) {
        switch (view.getId()) {
            case R.id.bt_startRecord: {
                //AudioFormat.CHANNEL_IN_STEREO双声道
                //AudioFormat.CHANNEL_IN_MONO单声道
                int bufferSize = 5 * 2 * 16000;
                Toast.makeText(this, "录音开始", Toast.LENGTH_SHORT).show();
                AudioManager.getInstance().startRecord(AudioFormat.CHANNEL_IN_MONO, bufferSize,
                        new AudioManager.AudioRecordCallback() {
                            @Override
                            public void onFrameDataIn(byte[] data) {
                                //data就是录制的识别数据
                                Log.d(TAG, "data.size:" + data.length);
                            }
                        });
            }
            break;
            case R.id.bt_stopRecord: {
                String fileName = AudioManager.getInstance().stopRecord();
                Toast.makeText(this, "录音文件以保存到："+fileName, Toast.LENGTH_LONG).show();
            }
            break;
            default:
                break;
        }
    }

    @Override
    protected void onDestroy() {
        super.onDestroy();
        AudioManager.getInstance().stopRecord();
    }
}
